==> cmsmadesimple-1.6.6.tgz: cms/modules/TinyMCE/lang/ext/nl_NL.php <==
<?php
$lang['friendlyname'] = 'TinyMCE WYSIWYG Editor';
$lang['uninstalled'] = 'Module gede&iuml;nstalleerd.';
$lang['installed'] = 'Module versie %s ge&iuml;nstalleerd.';
$lang['stripbackgroundtags'] = 'Verwijder &quot;background&quot; tags uit CSS';
$lang['stiptags_help'] = 'Deze opties probeert de background-type instellingen van de stylesheet te verwijderen.';
$lang['source_formatting_text'] = 'Broncodeformattering op de HTML-uitvoer toepassen ';
$lang['dropdownblockformats_text'] = 'Bloktypen in keuzemenu';
$lang['allowtables'] = 'Sta tabelbewerkingen toe';
$lang['newlinestyle_text'] = 'Nieuwe regelopmaak';
$lang['pstyle'] = 'p-stijl';
$lang['brstyle'] = 'br-stijl';
$lang['usecompressiontext'] = 'Gebruik gz compressie';
$lang['usecompressionhelp'] = 'Deze instelling kan TinyMCE sneller laten laden. Op sommige systemen kan TinyMCE hierdoor niet meer werken. Pas dus op met het gebruiken hiervan.';
$lang['forcedrootblocktext'] = 'Forceer inhoud in een Paragraaf blok';
$lang['forcedrootblockhelp'] = 'Plaats de inhoud automatisch in een &amp;lt;p&amp;gt;-tag';
$lang['filepickerstyle'] = 'Filepicker stijl';
$lang['filepickersize'] = 'Filepicker afmetingen';
$lang['allowuploadtext'] = 'Sta opladen en aanmaken van folders in FilePicker toe';
$lang['allowscalingtext'] = 'Sta on-the-fly verschaling van ge&uuml;ploade afbeeldingen toe';
$lang['scalingdimensionstext'] = 'Standaard dimensies';
$lang['resizeto'] = 'Verschaal naar:';
$lang['useadvancedprofile'] = 'Gebruik geavanceerd TinyMCE-profiel';
$lang['saveprofile'] = 'Profiel opslaan';
$lang['profilesaved'] = 'Het profiel is opgeslagen';
$lang['profiles_tab'] = 'Profielen';
$lang['advanced_backend_toolbars'] = 'Geavanceerde backend profielinstellingen';
$lang['savestyles'] = 'Stijlen opslaan';
$lang['allowadvancedprofile'] = 'Sta het gebruik van geavanceerde profielen in TinyMCE toe';
$lang['showfilemanagement'] = 'Laat bestandsbeheer opties zien';
$lang['showfilemanagementhelp'] = 'Laat bestandsbeheer opties zien, zoals upload, aanmaken map en verwijder bestand, als de gebruiker daartoe de rechten heeft.';
$lang['deleteconfirmation'] = 'Weet u zeker dat u dit bestand wilt verwijderen?';
$lang['deletefilesuccess'] = 'is verwijderd';
$lang['deletefilefila'] = 'kan niet worden verwijderd';
$lang['cannotreadconfig'] = 'Kan het bestand tinyconfig.php niet lezen, waardoor TinyMCE waarschijnlijk niet zal werken. Controleer de permissies van het bestand en de bovenliggende folders, welke leesrechten moeten hebben, maar enkel schrijfrechten mogen hebben voor de eigenaar.';
$lang['filenameonly'] = 'Toon bestandsnamen';
$lang['thumbnailsonly'] = 'Toon miniaturen';
$lang['showthumbnailfilestext'] = 'Laat de bestanden zien in een lijst met miniaturen';
$lang['filenameandthumbnails'] = 'Toon zowel bestandsnamen en miniaturen';
$lang['skinstext'] = 'Skin ';
$lang['skinvariationtext'] = 'Skin variant';
$lang['advancedwarning'] = '<strong>Let op!<br/>Het wijzigen van deze instellingen kan het gevolg hebben dat TinyMCE stopt met functioneren of dat de door TinyMCE gegenereerde code niet meer correct is. Wijzig dit alleen als u weet wat u doet! Raadpleeg eerst de TinyMCE website voordat u hiermee gaat knutselen.</strong> ';
$lang['entityencoding_text'] = 'Coderen van entiteiten';
$lang['rawencoding'] = 'Grove codering (snelst, werkt in de meeste gevallen)';
$lang['namedencoding'] = 'Benoemde codering (zoals &nbsp;)';
$lang['numericencoding'] = 'Numerieke codering (zoals &amp;#160;)';
$lang['show_path_text'] = 'Het pad van het element onderaan in de editor tonen.';
$lang['toolbar_tab'] = 'Werkbalk';
$lang['toolbar_help'] = 'Deze opties moeten een kommagescheidenlijst van knoppen/control-namen bevatten die in de werkbalk worden opgenomen. De karakter | kan worden gebruikt in plaats van het woord &#039;seperator&#039;';
$lang['toolbar_text'] = 'Werkbalk';
$lang['toolbarhelptext'] = 'Klik hier om de werkbalk-instructies op TinyMCE-wiki te bekijken.';
$lang['editor_width_text'] = 'Breedte van het editor veld';
$lang['editor_height_text'] = 'Hoogte van het editor veld';
$lang['auto'] = 'Automatisch';
$lang['or'] = 'of';
$lang['datetimeformat_text'] = 'Datum/Tijd formaat';
$lang['timetext'] = 'Tijd';
$lang['datetext'] = 'Datum';
$lang['datetimeformat_help'] = 'Klik hier voor help voor de datum/tijd formattering';
$lang['extraconfigtext'] = 'Extra configuratie';
$lang['extraconfighelp'] = 'Controleer TinyMCE-wiki voor instructies';
$lang['customdropdowntext'] = 'Specifieke dropdown';
$lang['customdropdownhelp'] = 'Plaats naar eigen wens stukje code of tekst in een dropdown menu.<br /> 
Erg gemakkelijk voor het toepassen van TAG&#039;s enz.<br />
Het menu wordt in de werkbalk geplaatst door het vermelden van &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'Startup ingeschakeld';
$lang['startenabledhelp'] = 'Wegvinken start TinyMCE in uitgeschakelde modus. Dient te worden gebruikt samen met de toggle-knop.';
$lang['loadcmslinkertext'] = 'Laadt de CMS Interne Linker';
$lang['loadcmslinkerhelp'] = 'Dit genereert de javascript-code die nodig is om de &#039;cmslinker&#039; toe te voegen aan de werkbalk.';
$lang['cmslinkerstyletext'] = 'CMS-linker link-style ';
$lang['cmsselflinkstyle'] = '{cms_selflink}-stijl (ondersteund pretty urls)';
$lang['ahrefstyle'] = '<a href>-stijl (ondersteund geen pretty urls)';
$lang['relativeurlstext'] = 'Genereer relatieve urls';
$lang['forcecleanpastetext'] = 'Forceer opschonen na plakken';
$lang['forcecleanpastehelp'] = 'Deze moet geactiveerd worden om vreemde opmaak te verwijderen bij plakken vanuit Word etc...';
$lang['bodycss_text'] = 'Body tag CSS ';
$lang['bodycss_help'] = 'Wordt toegevoegd aan de CSS Body Div. Tip: Om voor de achtergrondkleur wit te kiezen, typt u in de volgende regel: &quot;background-color:white;&quot;';
$lang['includeonlyscreencss_text'] = 'Gebruik enkel &#039;screen&#039; CSS';
$lang['includeonlyscreencss_help'] = 'Selecteren van deze optie zorgt ervoor dat enkel &#039;screen&#039;-mediatype kan worden geselecteerd in TinyMCE handles.';
$lang['usestaticconfigtext'] = 'Gebruik statische configuratiebestand';
$lang['usestaticconfighelp'] = 'Dit kan helpen om TinyMCE te laten werken op systemen waar de Host, statistieken etc. in alle output plaats, waarmee dynamische javascripts niet correct zijn.';
$lang['usestaticconfigwarning'] = 'Waarschuwing! Je hebt het statische configuratiebestand ingeschakeld, maar je /tmp/ map is niet schrijfbaar. Dit zorgt ervoor dat het statische configuratiebestand niet kan worden weggeschreven, waardoor TinyMCE niet zal werken.';
$lang['showtogglebutton_text'] = 'Aanvinkvak tonen om WYSIWYG aan of uit te zetten';
$lang['togglewysiwyg'] = 'WYSIWYG aan of uit zetten';
$lang['styles_tab'] = 'CSS-stijlen';
$lang['styles_help'] = 'Als u dit veld leeg laat dan zal TinyMCE alle bestaande CSS stylen overnemen in de werkbalk van de editor voor class-toepassingen.  
Als de gebruiker de keus moet krijgen uit slechts enkele stijlen maak dan hier een lijst: &quot;eigennaam1=stijl1; eigennaam2=stijl2&quot;.
&quot;stijl1&quot; is een css-class uit uw eigen stylesheet.
Na het instellen kunt u in onderstaande editor de instellingen testen.';
$lang['css_styles_text'] = 'Stijlen';
$lang['accessdenied'] = 'Toegang geweigerd. Zorg dat u beschikt over voldoende rechten.';
$lang['error'] = 'Fout';
$lang['submit'] = 'Versturen';
$lang['update'] = 'Bijwerken';
$lang['savesettings'] = 'Instellingen opslaan';
$lang['settings'] = 'Instellingen';
$lang['settingssaved'] = 'Instellingen zijn opgeslagen';
$lang['saveadvanced'] = 'Geavanceerde instellingen opslaan';
$lang['advancedsaved'] = 'Geavanceerde instellingen opgeslagen';
$lang['toolbarsaved'] = 'Werkbalk is opgeslagen';
$lang['stylessaved'] = 'Stijlen zijn opgeslagen';
$lang['testareatext'] = '<p>Testgebied, bestaande tekst zal niet beschadigd worden tijdens het experimenteren in dit gebied...</p>';
$lang['reset'] = 'Herstel instellingen';
$lang['resetall'] = 'Herstel alle instellingen naar standaard waarden';
$lang['confirmreset'] = 'Weet je zeker dat deze instellingen naar standaard moeten worden gezet?';
$lang['confirmresetall'] = 'Weet je zeker dat ALLE instellingen naar standaard moeten worden gezet?';
$lang['settingsreset'] = 'De instellingen zijn hersteld';
$lang['allsettingsreset'] = 'Alle instellingen zijn hersteld';
$lang['upgraded'] = 'is ge&uuml;pgrade naar versie %s';
$lang['customdropdown'] = 'Specifiek dropdown-menu';
$lang['cmsmslinker'] = 'Voeg een interne link toe';
$lang['backend_toolbars'] = 'Backend profiel instellingen';
$lang['frontend_toolbars'] = 'Frontend profiel instellingen';
$lang['plugins_tab'] = 'Plugins ';
$lang['plugins_help'] = 'Kies de plugins die je wilt activeren. Documentatie kan <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">hier</a> worden gevonden.';
$lang['plugins_text'] = 'Plugins ';
$lang['saveplugins'] = 'Bewaar plugins';
$lang['pluginssaved'] = 'Plugins opgeslagen';
$lang['youareintext'] = 'Je bent in';
$lang['loadstylesheettext'] = 'Stylesheet laden voor de &#039;content&#039; (aanbevolen)';
$lang['extrastylestext'] = 'Toevoegingen aan stylesheets';
$lang['extrastyleshelp'] = 'CSS-logica die hier wordt toegevoegd, zal aan de stylesheet worden toegevoegd die door TinyMCE wordt toegepast, na het openen van de CMSms stylesheet';
$lang['uploadnewfile'] = 'Nieuw bestand';
$lang['uploadfile'] = 'Upload ';
$lang['createnewdir'] = 'Nieuwe Map';
$lang['createdir'] = 'Maak';
$lang['nodirname'] = 'Geen mapnaam opgegeven';
$lang['direxists'] = 'Map bestaat reeds';
$lang['newdircreated'] = 'Nieuwe map aangemaakt';
$lang['newdirfailed'] = 'Fout opgetreden bij aanmaken van een map';
$lang['nofile'] = 'Er is geen bestand opgeladen';
$lang['filetoobig'] = 'Opgeladen bestand is te groot';
$lang['uploadfailed'] = 'Fout bij verplaatsen bestand';
$lang['fileuploaded'] = 'Bestand opgeladen';
$lang['filepickertitle'] = 'CMS Made Simple Bestandsselectie';
$lang['success'] = 'Gelukt';
$lang['fileoperations'] = 'Bestandbewerkingen';
$lang['thousanddelimiter'] = ', ';
$lang['size'] = 'Afmetingen';
$lang['dimensions'] = 'BxH';
$lang['advanced_tab'] = 'Geavanceerd';
$lang['help'] = '	<h3>Wat doet het?</h3>
	<p>TinyMCE is de standaard-editor van CMS Made Simple. Het is gebaseerd op WYSIWYG-principe.</p>
	<h3>Hoe gebruik ik het?</h3>
	<p>Zodra u geformatteerde tekst kunt invoeren of bewerken is TinyMCE binnen het tekstgebied beschikbaar.</p>
	<p>Stel de juiste rechten in bij Gebruikers/Groepen -> Groepsrechten voor het aanpassen van de TinyMCE-instellingen.</p>

<h3>Wat te doen bij fouten?</h3>
	Some people have trouble with tiny not showing up upon installation or upgrading. Here is a checklist of 
	things you can try before contacting me for further support.
	<br/>
	<ul>
	<li>1. Please, please, try to reupload the modules/TinyMCE dir to your server. You&#039;d be amazed how many times this has helped people.</li>
	<li>2. Try to switch on the Static Config option. Note that this requires your /tmp/-dir to be writable by the webserver</li>
	<li>3. If upgrading, please try to reset all settings. Not nice if you&#039;ve done a lot of customization, I know, but a lot of things changes from 2.3.x to 2.4.x series of the module.
	<li>4. Try enabling the static config option in advanced settings. This works better on some systems (like CGI-based)
	</ul>
	<br/>
		
';
$lang['qca'] = 'P0-603614347-1252681532014';
$lang['utma'] = '156861353.36781539.1252748587.1254296120.1254498045.34';
$lang['utmz'] = '156861353.1253629210.22.11.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,37218.new.html';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.8.2p0.tgz: cms/modules/TinyMCE/lang/ext/nl_NL.php <==
<?php
$lang['friendlyname'] = 'TinyMCE WYSIWYG Editor';
$lang['uninstalled'] = 'Module gede&iuml;nstalleerd.';
$lang['installed'] = 'Module versie %s ge&iuml;nstalleerd.';
$lang['stripbackgroundtags'] = 'Verwijder &quot;background&quot; tags uit CSS';
$lang['stiptags_help'] = 'Deze opties probeert de background-type instellingen van de stylesheet te verwijderen.';
$lang['source_formatting_text'] = 'Broncodeformattering op de HTML-uitvoer toepassen ';
$lang['dropdownblockformats_text'] = 'Bloktypen in keuzemenu';
$lang['allowtables'] = 'Sta tabelbewerkingen toe';
$lang['newlinestyle_text'] = 'Nieuwe regelopmaak';
$lang['pstyle'] = 'p-stijl';
$lang['brstyle'] = 'br-stijl';
$lang['usecompressiontext'] = 'Gebruik gz compressie';
$lang['usecompressionhelp'] = 'Deze instelling kan TinyMCE sneller laten laden. Op sommige systemen kan TinyMCE hierdoor niet meer werken. Pas dus op met het gebruiken hiervan.';
$lang['forcedrootblocktext'] = 'Forceer inhoud in een Paragraaf blok';
$lang['forcedrootblockhelp'] = 'Plaats de inhoud automatisch in een p-tag';
$lang['filepickerstyle'] = 'Filepicker stijl';
$lang['filepickersize'] = 'Filepicker afmetingen';
$lang['allowuploadtext'] = 'Sta opladen en aanmaken van folders in FilePicker toe';
$lang['allowscalingtext'] = 'Sta on-the-fly verschaling van ge&uuml;ploade afbeeldingen toe';
$lang['scalingdimensionstext'] = 'Standaard dimensies';
$lang['resizeto'] = 'Verschaal naar:';
$lang['makethumbnail'] = 'Maak een miniatuur wanneer de afbeelding wordt ge&uuml;pload';
$lang['useadvancedprofile'] = 'Gebruik geavanceerd TinyMCE-profiel';
$lang['saveprofile'] = 'Profiel opslaan';
$lang['profilesaved'] = 'Het profiel is opgeslagen';
$lang['profiles_tab'] = 'Profielen';
$lang['advanced_backend_toolbars'] = 'Geavanceerde backend profielinstellingen';
$lang['savestyles'] = 'Stijlen opslaan';
$lang['allowadvancedprofile'] = 'Sta het gebruik van geavanceerde profielen in TinyMCE toe';
$lang['showfilemanagement'] = 'Laat bestandsbeheer opties zien';
$lang['showfilemanagementhelp'] = 'Laat bestandsbeheer opties zien, zoals upload, aanmaken map en verwijder bestand, als de gebruiker daartoe de rechten heeft.';
$lang['restrictdirs'] = 'Beperk gebruikerstoegang tot de servermappen';
$lang['restrictdirshelp'] = 'Dit zal de bestandsbeheer-mogelijkheden van de gebruiker beperken tot een submap van &#039;uploads&#039; die dezelfde naam draagt als de loginnaam van de gebruiker. Als deze map niet bestaat dan zal deze worden aangemaakt. Let op, dit werkt op het moment alleen met de standaard mapnamen, uploads/images. Het kan zijn dat dit in de toekomst nog verandert.';
$lang['deleteconfirmation'] = 'Weet u zeker dat u dit bestand wilt verwijderen?';
$lang['deletefilesuccess'] = 'is verwijderd';
$lang['deletefilefailed'] = 'kan niet worden verwijderd';
$lang['deletesubdirfailed'] = 'kan niet worden verwijderd';
$lang['deletesubdirsuccess'] = 'is succesvol verwijderd';
$lang['deletedirconfirmation'] = 'Weet u zeker dat deze lege submap moet worden verwijderd?';
$lang['deletedir'] = 'Verwijder lege submap';
$lang['deletefile'] = 'Verwijder Bestand';
$lang['cannotreadconfig'] = 'Kan het bestand tinyconfig.php niet lezen, waardoor TinyMCE waarschijnlijk niet zal werken. Controleer de permissies van het bestand en de bovenliggende folders, welke leesrechten moeten hebben, maar enkel schrijfrechten mogen hebben voor de eigenaar.';
$lang['filenameonly'] = 'Toon bestandsnamen';
$lang['thumbnailsonly'] = 'Toon miniaturen';
$lang['showthumbnailfilestext'] = 'Toon de miniatuur-bestanden in de lijst met bestanden';
$lang['filenameandthumbnails'] = 'Toon zowel bestandsnamen en miniaturen';
$lang['skinstext'] = 'Skin ';
$lang['skinvariationtext'] = 'Skin variant';
$lang['advancedwarning'] = '<strong>Let op!<br/>Het wijzigen van deze instellingen kan het gevolg hebben dat TinyMCE stopt met functioneren of dat de door TinyMCE gegenereerde code niet meer correct is. Wijzig dit alleen als u weet wat u doet! Raadpleeg eerst de TinyMCE website voordat u hiermee gaat knutselen.</strong> ';
$lang['entityencoding_text'] = 'Coderen van entiteiten';
$lang['rawencoding'] = 'Grove codering (snelst, werkt in de meeste gevallen)';
$lang['namedencoding'] = 'Benoemde codering (zoals &nbsp;)';
$lang['numericencoding'] = 'Numerieke codering (zoals &amp;#160;)';
$lang['show_path_text'] = 'Het pad van het element onderaan in de editor tonen.';
$lang['toolbar_tab'] = 'Werkbalk';
$lang['toolbar_help'] = 'Deze opties moeten een kommagescheidenlijst van knoppen/control-namen bevatten die in de werkbalk worden opgenomen. De karakter | kan worden gebruikt in plaats van het woord &#039;seperator&#039;';
$lang['toolbar_text'] = 'Werkbalk';
$lang['toolbarhelptext'] = 'Klik hier om de werkbalk-instructies op TinyMCE-wiki te bekijken.';
$lang['editor_width_text'] = 'Breedte van het editor veld';
$lang['editor_height_text'] = 'Hoogte van het editor veld';
$lang['auto'] = 'Automatisch';
$lang['or'] = 'of';
$lang['allowresizing'] = 'Sta het verschalen in de editor toe';
$lang['resizenone'] = 'Verschalen niet toestaan';
$lang['resizeboth'] = 'Sta het verschalen in beide richtingen toe';
$lang['resizeheight'] = 'Sta alleen het verschalen in de hoogte toe';
$lang['datetimeformat_text'] = 'Datum/Tijd formaat';
$lang['timetext'] = 'Tijd';
$lang['datetext'] = 'Datum';
$lang['datetimeformat_help'] = 'Klik hier voor help voor de datum/tijd formattering';
$lang['extraconfigtext'] = 'Extra configuratie';
$lang['extraconfighelp2'] = 'Een commando per regel, er worden voor en achter deze inhoud komma&#039;s geplaatst. Lees de TinyMCE-wiki voor meer instructies.';
$lang['customdropdowntext'] = 'Specifieke dropdown';
$lang['customdropdownhelp'] = 'Plaats naar eigen wens stukje code of tekst in een dropdown menu.<br /> 
Erg gemakkelijk voor het toepassen van TAG&#039;s enz.<br />
Het menu wordt in de werkbalk geplaatst door het vermelden van &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'Startup ingeschakeld';
$lang['startenabledhelp'] = 'Wegvinken start TinyMCE in uitgeschakelde modus. Dient te worden gebruikt samen met de toggle-knop.';
$lang['loadcmslinkertext'] = 'Laadt de CMS Interne Linker';
$lang['loadcmslinkerhelp'] = 'Dit genereert de javascript-code die nodig is om de &#039;cmslinker&#039; toe te voegen aan de werkbalk.';
$lang['cmslinkerstyletext'] = 'CMS-linker link-style ';
$lang['cmsselflinkstyle'] = 'cms_selflink-stijl';
$lang['ahrefstyle'] = 'a href-stijl';
$lang['relativeurlstext'] = 'Genereer relatieve urls';
$lang['forcecleanpastetext'] = 'Forceer opschonen na plakken';
$lang['forcecleanpastehelp'] = 'Deze moet geactiveerd worden om vreemde opmaak te verwijderen bij plakken vanuit Word etc...';
$lang['bodycss_text'] = 'Body tag CSS ';
$lang['bodycss_help'] = 'Wordt toegevoegd aan de CSS Body Div. Tip: Om voor de achtergrondkleur wit te kiezen, typt u in de volgende regel: &quot;background-color:white;&quot;';
$lang['includeonlyscreencss_text'] = 'Gebruik alleen &#039;screen&#039; CSS';
$lang['includeonlyscreencss_help'] = 'Selecteren van deze optie zorgt ervoor dat enkel &#039;screen&#039;-mediatype kan worden geselecteerd in TinyMCE handles.';
$lang['usestaticconfigtext'] = 'Gebruik statische configuratiebestand';
$lang['usestaticconfighelp'] = 'Dit kan helpen om TinyMCE te laten werken op systemen waar de Host, statistieken etc. in alle output plaats, waarmee dynamische javascripts niet correct zijn.';
$lang['usestaticconfigwarning'] = 'Waarschuwing! Je hebt het statische configuratiebestand ingeschakeld, maar je /tmp/ map is niet schrijfbaar. Dit zorgt ervoor dat het statische configuratiebestand niet kan worden weggeschreven, waardoor TinyMCE niet zal werken.';
$lang['ignoremodifyfilestext'] = 'Negeer de &#039;Modify Files&#039; rechten voor de FilePicker';
$lang['ignoremodifyfileshelp'] = 'Waarschuwing! Hiermee staat u bepaalde bestandsbeheer rechten toe, ook als voor deze gebruikersgroep het &#039;Modify Files&#039; recht niet is ingesteld. Deze optie kan goed worden gebruikt in combinatie met de optie &quot;Beperk gebruikerstoegang tot de servermappen&quot;';
$lang['showtogglebutton_text'] = 'Aanvinkvak tonen om WYSIWYG aan of uit te zetten';
$lang['togglewysiwyg'] = 'WYSIWYG aan of uit zetten';
$lang['styles_tab'] = 'CSS-stijlen';
$lang['styles_help'] = 'Als u dit veld leeg laat dan zal TinyMCE alle bestaande CSS stylen overnemen in de werkbalk van de editor voor class-toepassingen.  
Als de gebruiker de keus moet krijgen uit slechts enkele stijlen maak dan hier een lijst: &quot;eigennaam1=stijl1; eigennaam2=stijl2&quot;.
&quot;stijl1&quot; is een css-class uit uw eigen stylesheet.
Na het instellen kunt u in onderstaande editor de instellingen testen.';
$lang['css_styles_text'] = 'Stijlen';
$lang['accessdenied'] = 'Toegang geweigerd. Zorg dat u beschikt over voldoende rechten.';
$lang['error'] = 'Fout!';
$lang['submit'] = 'Versturen';
$lang['update'] = 'Bijwerken';
$lang['savesettings'] = 'Instellingen opslaan';
$lang['settings'] = 'Instellingen';
$lang['settingssaved'] = 'Instellingen zijn opgeslagen';
$lang['saveadvanced'] = 'Geavanceerde instellingen opslaan';
$lang['advancedsaved'] = 'Geavanceerde instellingen opgeslagen';
$lang['toolbarsaved'] = 'Werkbalk is opgeslagen';
$lang['stylessaved'] = 'Stijlen zijn opgeslagen';
$lang['testareatext'] = '<p>Testgebied, bestaande tekst zal niet beschadigd worden tijdens het experimenteren in dit gebied...</p>';
$lang['reset'] = 'Herstel instellingen';
$lang['resetall'] = 'Herstel alle instellingen naar standaard waarden';
$lang['confirmreset'] = 'Weet je zeker dat deze instellingen naar standaard moeten worden gezet?';
$lang['confirmresetall'] = 'Weet je zeker dat ALLE instellingen naar standaard moeten worden gezet?';
$lang['settingsreset'] = 'De instellingen zijn hersteld';
$lang['allsettingsreset'] = 'Alle instellingen zijn hersteld';
$lang['upgraded'] = 'is ge&uuml;pgrade naar versie %s';
$lang['customdropdown'] = 'Specifiek dropdown-menu';
$lang['cmsmslinker'] = 'Voeg een interne link toe';
$lang['backend_toolbars'] = 'Backend profiel instellingen';
$lang['frontend_toolbars'] = 'Frontend profiel instellingen';
$lang['plugins_tab'] = 'Plugins ';
$lang['plugins_help'] = 'Kies de plugins die je wilt activeren. Documentatie kan <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">hier</a> worden gevonden.';
$lang['plugins_text'] = 'Plugins ';
$lang['saveplugins'] = 'Plugins opslaan';
$lang['pluginssaved'] = 'Plugins opgeslagen';
$lang['plugins_module'] = 'Module plugins';
$lang['plugins_common'] = 'Algemene plugins';
$lang['module'] = 'Module ';
$lang['description'] = 'Omschrijving';
$lang['plugin'] = 'Plugin ';
$lang['youareintext'] = 'U bent in';
$lang['loadstylesheettext'] = 'Stylesheet laden voor de &#039;content&#039; (aanbevolen)';
$lang['extrastylestext'] = 'Toevoegingen aan stylesheets';
$lang['extrastyleshelp'] = 'CSS-logica die hier wordt toegevoegd, zal aan de stylesheet worden toegevoegd die door TinyMCE wordt toegepast, na het openen van de CMSms stylesheet';
$lang['uploadnewfile'] = 'Nieuw bestand';
$lang['uploadfile'] = 'Upload ';
$lang['createnewdir'] = 'Nieuwe Map';
$lang['createdir'] = 'Maak';
$lang['nodirname'] = 'Geen mapnaam opgegeven';
$lang['direxists'] = 'Map bestaat reeds';
$lang['newdircreated'] = 'Nieuwe map aangemaakt';
$lang['newdirfailed'] = 'Fout opgetreden bij aanmaken van een map';
$lang['nofile'] = 'Er is geen bestand opgeladen';
$lang['filetoobig'] = 'Opgeladen bestand is te groot';
$lang['containsillegalchars'] = 'De bestandsnaam bevat &eacute;&eacute;n of meer niet-toegestane karakters (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['uploadfailed'] = 'Fout bij verplaatsen bestand';
$lang['fileuploaded'] = 'Bestand opgeladen';
$lang['filepickertitle'] = 'CMS Made Simple Bestandsselectie';
$lang['success'] = 'Gelukt';
$lang['fileoperations'] = 'Bestandbewerkingen';
$lang['thousanddelimiter'] = ', ';
$lang['size'] = 'Afmetingen';
$lang['dimensions'] = 'BxH';
$lang['advanced_tab'] = 'Geavanceerd';
$lang['help'] = '	<h3>What does this do? </h3>
	<p>Enables a TinyMCE to be used as a WYSIWYG.</p>
	<h3>How do I use it?</h3>
	<p>Install it, then go to User Preferences and Set TinyMCE to be your wysiwyg of choice.</p>
  <h3>Spellchecker</h3>
  <p>As of version 2.6.0, TinyMCE includes an online spellchecker. Please notice that SSL must be turned on in your server-configuration in order for this to work. On some setups this option is called php_openssl but that may vary</p>
	<h3>Troubleshooting</h3>
	Some people have trouble with tiny not showing up upon installation or upgrading. Here is a checklist of 
	things you can try before contacting me for further support.
	<br/>
	<ul>
	<li>1. Please, please, try to reupload the modules/TinyMCE dir to your server. You&#039;d be amazed how many times this has helped people.</li>
	<li>2. Try to switch on the Static Config option. Note that this requires your /tmp/-dir to be writable by the webserver</li>
	<li>3. If upgrading, please try to reset all settings. Not nice if you&#039;ve done a lot of customization, I know, but a lot of things changes from 2.3.x to 2.4.x series of the module.
	<li>4. Try enabling the static config option in advanced settings. This works better on some systems (like CGI-based)
	</ul>
	<br/>
		

		
';
$lang['utma'] = '156861353.509382990.1276370458.1276511809.1276521520.16';
$lang['utmz'] = '156861353.1276457496.6.2.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/board,64.0.html';
$lang['qca'] = 'P0-26515958-1276370458481';
$lang['utmb'] = '156861353.2.10.1276521520';
$lang['utmc'] = '156861353';
?>
